REM
REM **********************************************************************
REM Filename:	add_constraints.sql    
REM Author:	Darryl Smith - Active Database Solutions, Inc.
REM Date:	1/31/94
REM
REM Description:
REM  	This programs create all of the alter table statements needed to 
REM add the constraints to the schema from an existing schema.
REM
REM Comments:
REM	The input variable is schema owner.  The output file is 
REM add_cons.lst
REM **********************************************************************
REM
REM
column tbl_alias noprint
column cons_alias noprint
column in_what_order noprint
column in_what_order2 noprint
@schema_start
spool &lst_dir./&Schema_Owner._add_constraints.lst
select 'REM' from dual;
select 'REM Alter table for the Constraints Section' from Dual;
select 'REM' from dual;
select 'REM' from dual;
select table_name tbl_alias, constraint_name cons_alias, 
	01 in_what_order,1 in_what_order2,
	'Alter table '||table_name||' Add '||
	'Constraint '||constraint_name||
	decode(constraint_type,'U',' Unique ','R',' Foreign Key ',
		'P',' Primary Key ',null)
from all_constraints
where owner = upper('&Schema_Owner') and
	constraint_type != 'C'
union
select cons.table_name tbl_alias, cons.constraint_name cons_alias, 
	02 in_what_order,cons.position in_what_order2,
	'     '||decode(cons.position,1,'(',0,'(',' ')||cons.column_name||
	decode(max(grpcons.position),cons.position,')',',')
from all_cons_columns cons,all_cons_columns grpcons, all_constraints allc
where allc.owner = upper('&Schema_Owner') and
	constraint_type != 'C' and
	cons.owner = allc.owner and
	cons.table_name = allc.table_name and
	cons.constraint_name = allc.constraint_name and
	grpcons.table_name = cons.table_name and
	grpcons.constraint_name = cons.constraint_name and
	grpcons.owner = cons.owner
group by cons.table_name,cons.constraint_name,cons.position,cons.column_name
union
select origcon.table_name tbl_alias, origcon.constraint_name cons_alias, 
	03 in_what_order,1 in_what_order2,
	'References '||refcon.table_name
from all_constraints origcon, all_constraints refcon
where origcon.owner = upper('&Schema_Owner') and
	origcon.constraint_type != 'C' and
	refcon.owner = origcon.r_owner and
	refcon.constraint_name = origcon.r_constraint_name
union
select origcon.table_name tbl_alias, origcon.constraint_name cons_alias, 
	04 in_what_order,cons.position in_what_order2,
	'     '||decode(cons.position,1,'(',' ')||cons.column_name||
	decode(max(grpcons.position),cons.position,')',',')
from all_constraints origcon,all_constraints refcon,
	all_cons_columns cons,all_cons_columns grpcons
where origcon.owner = upper('&Schema_Owner') and
	origcon.constraint_type != 'C' and
	refcon.owner = origcon.r_owner and
	refcon.constraint_name = origcon.r_constraint_name and
	cons.owner = refcon.owner and
	cons.constraint_name = refcon.constraint_name and
	cons.table_name = refcon.table_name and
	grpcons.owner = cons.owner and
	grpcons.table_name = cons.table_name and
	grpcons.constraint_name = cons.constraint_name
group by origcon.table_name,origcon.constraint_name,
	cons.position,cons.column_name
union
select table_name tbl_alias,index_name  cons_alias, 
	5 in_what_order, 1 in_what_order2,
	' Using Index Pctfree '||pct_free field_attrs
from all_indexes
where owner = upper('&schema_owner') and
	index_name in (select constraint_name from all_constraints
			where owner = upper('&schema_owner')
				and constraint_type in ('P','U'))
union
select table_name tbl_alias,index_name  cons_alias, 
	5 in_what_order1, 2 in_what_order2,
	' Tablespace '||tablespace_name field_attrs
from all_indexes
where owner = upper('&schema_owner') and
	index_name in (select constraint_name from all_constraints
			where owner = upper('&schema_owner')
				and constraint_type in ('P','U'))
union
select table_name tbl_alias,index_name  cons_alias, 
	5 in_what_order1, 3 in_what_order2,
	'Storage (Initial    '||initial_extent||
	'    Next       '||next_extent field_attrs
from all_indexes
where owner = upper('&schema_owner') and
	index_name in (select constraint_name from all_constraints
			where owner = upper('&schema_owner')
				and constraint_type in ('P','U'))
union
select table_name tbl_alias,index_name  cons_alias, 
	5 in_what_order1, 4 in_what_order2,
	'         Minextents '||min_extents|| 
	'    Maxextents '||max_extents field_attrs
from all_indexes
where owner = upper('&schema_owner') and
	index_name in (select constraint_name from all_constraints
			where owner = upper('&schema_owner')
				and constraint_type in ('P','U'))
union
select table_name tbl_alias,index_name  cons_alias, 
	5 in_what_order1, 5 in_what_order2,
	'         Pctincrease '||pct_increase||');' field_attrs
from all_indexes
where owner = upper('&schema_owner') and
	index_name in (select constraint_name from all_constraints
			where owner = upper('&schema_owner')
				and constraint_type in ('P','U'))
union
select table_name tbl_alias, constraint_name cons_alias, 
	6 in_what_order,1 in_what_order2,
	'REM' field_attrs
from all_constraints
where owner = upper('&Schema_Owner') and
	constraint_type != 'C'
order by 2 desc,1,3,4;
select 'REM' from dual;
select 'Exit;' from dual;
spool off;
exit;
