REM
REM **********************************************************************
REM Filename:	create_indexes.sql
REM Author:	Darryl Smith - Active Database Solutions, Inc.
REM Date:	1/31/94
REM
REM Description:
REM   This script generates the sql statements required to re-create 
REM the indexes in a schema.
REM
REM Comments:
REM	The input variable is the owner of the schema.  The output file
REM is create_indexes.lst.
REM **********************************************************************
REM
REM
column idx_alias noprint
column in_what_order1 noprint
column in_what_order2 noprint
column field_attrs format a78 heading 'None'
@schema_start
spool &lst_dir./&Schema_Owner._create_indexes.lst
select 'REM' from dual;
select 'REM' from dual;
select 'REM Create Indexes Section' from Dual;
select 'REM' from dual;
select	index_name idx_alias, 1 in_what_order1, 1 in_what_order2,
	'REM Create '||decode(uniqueness,'UNIQUE',uniqueness||' ',null)||
               'Index Command for: '||index_name format_attrs
from all_indexes
where owner = upper('&schema_owner') and
	index_name not in (select constraint_name from all_constraints
			where owner = upper('&schema_owner'))
union
select index_name idx_alias, 2 in_what_order1, 1 in_what_order2,
	'REM' format_attrs
from all_indexes
where owner = upper('&schema_owner') and
	index_name not in (select constraint_name from all_constraints
			where owner = upper('&schema_owner'))
union
select index_name idx_alias, 3 in_what_order1, 1 in_what_order2,
	'Create '||decode(uniqueness,'UNIQUE',uniqueness||' ',null)||
               'Index '||index_name||' On '||table_name||' (' format_attrs
from all_indexes
where owner = upper('&schema_owner') and
	index_name not in (select constraint_name from all_constraints
			where owner = upper('&schema_owner'))
union
select cols.index_name idx_alias, 4 in_what_order1, 
	cols.column_position in_what_order2,
	'    '||cols.column_name||
	decode(max(grpcols.column_position),
		cols.column_position,')',',') format_attrs
from all_ind_columns cols, all_ind_columns grpcols 
where	grpcols.index_name = cols.index_name and
	cols.index_owner = upper('&schema_owner') and
	cols.index_name not in (select constraint_name from all_constraints
			where owner = upper('&schema_owner'))
group by cols.index_name, cols.column_position, cols.column_name
union
select index_name idx_alias, 5 in_what_order1, 1 in_what_order2,
	' Pctfree '||pct_free
from all_indexes
where owner = upper('&schema_owner') and
	index_name not in (select constraint_name from all_constraints
			where owner = upper('&schema_owner'))
union
select index_name idx_alias, 6 in_what_order1, 1 in_what_order2,
	' Tablespace '||tablespace_name format_attrs
from all_indexes
where owner = upper('&schema_owner') and
	index_name not in (select constraint_name from all_constraints
			where owner = upper('&schema_owner'))
union
select index_name idx_alias, 7 in_what_order1, 1 in_what_order2,
	'Storage (Initial    '||initial_extent||
	'    Next       '||next_extent format_attrs
from all_indexes
where owner = upper('&schema_owner') and
	index_name not in (select constraint_name from all_constraints
			where owner = upper('&schema_owner'))
union
select index_name idx_alias, 8 in_what_order1, 1 in_what_order2,
	'         Minextents '||min_extents|| 
	'    Maxextents '||max_extents format_attrs
from all_indexes
where owner = upper('&schema_owner') and
	index_name not in (select constraint_name from all_constraints
			where owner = upper('&schema_owner'))
union
select index_name idx_alias, 9 in_what_order1, 1 in_what_order2,
	'         Pctincrease '||pct_increase||');' format_attrs
from all_indexes
where owner = upper('&schema_owner') and
	index_name not in (select constraint_name from all_constraints
			where owner = upper('&schema_owner'))
union
select index_name idx_alias, 10 in_what_order1, 1 in_what_order2,
	'REM' format_attrs
from all_indexes
where owner = upper('&schema_owner') and
	index_name not in (select constraint_name from all_constraints
			where owner = upper('&schema_owner'))
order by 1,2,3;
select 'Exit;' from dual;
spool off;
exit;
