REM
REM **********************************************************************
REM Filename:	create_schema.sql
REM Author:	Darryl Smith - Active Database Solutions, Inc.
REM Date:	1/31/94
REM
REM Description:
REM   This script generates the sql statements required to re-create 
REM the tables in a schema.
REM
REM Comments:
REM	The input variable is the owner of the schema.  The output file
REM is create_schema.lst.
REM **********************************************************************
REM
REM
column tbl_alias noprint
column in_what_order1 noprint
column in_what_order2 noprint
column field_attrs format a70 heading 'None'
column alias_tbl format a70
break on alias_tbl skip page
@schema_start
spool &lst_dir./&Schema_Owner._create_schema.lst
select 'REM' from dual;
select 'REM' from dual;
select 'REM Create Table Section' from Dual;
select 'REM' from dual;
select	table_name tbl_alias, 1 in_what_order1, 1 in_what_order2,
	'REM Create Table Command for: '||table_name format_attrs
from all_tables tab1
where owner = upper('&schema_owner')
union
select table_name tbl_alias, 2 in_what_order1, 1 in_what_order2,
	'REM' format_attrs
from all_tables
where owner = upper('&schema_owner')
union
select table_name tbl_alias, 3 in_what_order1, 1 in_what_order2,
	'Create table '||table_name||' (' format_attrs
from all_tables
where owner = upper('&schema_owner')
union
select cols.table_name tbl_alias, 4 in_what_order1, 
	cols.column_id in_what_order2,
	('    '||rpad(cols.column_name,31)||
	cols.data_type||
	decode(cols.data_type,'DATE',null,'NUMBER',decode(cols.data_precision,null,null,'('),'(')||
	decode(cols.data_type,'NUMBER',
		cols.data_precision||decode(cols.data_scale,null,null,','||cols.data_scale),'DATE',null,
		cols.data_length)||
	decode(cols.data_type,'DATE',null,'NUMBER',decode(cols.data_precision,null,null,')'),')')||
	decode(cols.nullable,'N',
	lpad('Not Null',25-decode(cols.data_type,'NUMBER',
		length(cols.data_precision)+length(cols.data_scale)+1,'DATE',-2,
		length(cols.data_length))-length(cols.data_type)),
	null)||
	decode(max(grpcols.column_id),cols.column_id,')',',')) format_attrs
from all_tab_columns cols, all_tab_columns grpcols 
where	grpcols.table_name = cols.table_name and
	cols.owner = upper('&schema_owner') and
        exists (select table_name from all_tables
                where cols.table_name = all_tables.table_name and
			all_tables.owner = upper('&schema_owner'))
group by cols.table_name, cols.column_id, cols.column_name,
	cols.data_type,cols.data_length,cols.data_precision,
	cols.data_scale,cols.nullable
union
select table_name tbl_alias, 5 in_what_order1, 1 in_what_order2,
	' Pctfree '||pct_free||
	' Pctused '||pct_used format_attrs
from all_tables
where owner = upper('&schema_owner')
union
select table_name tbl_alias, 6 in_what_order1, 1 in_what_order2,
	' Tablespace '||tablespace_name format_attrs
from all_tables
where owner = upper('&schema_owner')
union
select table_name tbl_alias, 7 in_what_order1, 1 in_what_order2,
	'Storage (Initial    '||initial_extent||'k'||
	'    Next       '||next_extent||'k' format_attrs
from all_tables
where owner = upper('&schema_owner')
union
select table_name tbl_alias, 8 in_what_order1, 1 in_what_order2,
	'         Minextents '||min_extents|| 
	'    Maxextents '||max_extents format_attrs
from all_tables
where owner = upper('&schema_owner')
union
select table_name tbl_alias, 9 in_what_order1, 1 in_what_order2,
	'         Pctincrease '||pct_increase||');' format_attrs
from all_tables
where owner = upper('&schema_owner')
union
select table_name tbl_alias, 10 in_what_order1, 1 in_what_order2,
	'REM' format_attrs
from all_tables
where owner = upper('&schema_owner')
order by 1,2,3;
select 'Exit;' from dual;
spool off;
exit;
